#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unliftio-core
version:              0.2.1.0
visibility:           public
id:                   unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
key:                  unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
license:              MIT
copyright:            2017-2020 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio-core#readme

synopsis:             The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>

category:             Control
abi:                  5869534dab9459457edd1877c4940030
exposed:              True
exposed-modules:      Control.Monad.IO.Unlift
hidden-modules:       Paths_unliftio_core
import-dirs:          /usr/lib/ghc-9.6.6/site-local/unliftio-core-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unliftio-core-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unliftio-core-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unliftio-core
hs-libraries:         HSunliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
depends:              base-4.18.2.1 transformers-0.6.1.0
haddock-interfaces:
    /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock

haddock-html:         /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

